==> ember-data-3.6.0.tgz: package/addon/-private/index.js <==
// public
export { default as Model } from './system/model/model';
export { default as Errors } from './system/model/errors';
export { default as Store } from './system/store';
export { default as DS } from './core';
export { default as belongsTo } from './system/relationships/belongs-to';
export { default as hasMany } from './system/relationships/has-many';
export { default as BuildURLMixin } from './adapters/build-url-mixin';
export { default as Snapshot } from './system/snapshot';
export { default as attr } from './attr';
export {
  AdapterError,
  InvalidError,
  UnauthorizedError,
  ForbiddenError,
  NotFoundError,
  ConflictError,
  ServerError,
  TimeoutError,
  AbortError,
  errorsHashToArray,
  errorsArrayToHash,
} from './adapters/errors';

// maybe public ?
export { default as normalizeModelName } from './system/normalize-model-name';
export { getOwner, modelHasAttributeOrRelationshipNamedType } from './utils';
export { default as coerceId } from './system/coerce-id';
export { default as parseResponseHeaders } from './utils/parse-response-headers';

export { default as isEnabled } from './features';
// `ember-data-model-fragments` relies on `RootState` and `InternalModel`
export { default as RootState } from './system/model/states';
export { default as InternalModel } from './system/model/internal-model';
export { default as RecordData } from './system/model/record-data';

export { PromiseArray, PromiseObject, PromiseManyArray } from './system/promise-proxies';

export { RecordArray, AdapterPopulatedRecordArray } from './system/record-arrays';

export { default as ManyArray } from './system/many-array';
export { default as RecordArrayManager } from './system/record-array-manager';
export { default as Relationship } from './system/relationships/state/relationship';

// Should be a different Repo ?
export { default as DebugAdapter } from './system/debug/debug-adapter';

// Used by tests
export { default as diffArray } from './system/diff-array';
export { default as SnapshotRecordArray } from './system/snapshot-record-array';

==> ember-data-3.8.0.tgz: package/addon/-private/index.js <==
// public
export { default as Model } from './system/model/model';
export { default as Errors } from './system/model/errors';
export { default as Store } from './system/store';
export { default as DS } from './core';
export { default as belongsTo } from './system/relationships/belongs-to';
export { default as hasMany } from './system/relationships/has-many';
export { default as BuildURLMixin } from './adapters/build-url-mixin';
export { default as Snapshot } from './system/snapshot';
export { default as attr } from './attr';
export {
  AdapterError,
  InvalidError,
  UnauthorizedError,
  ForbiddenError,
  NotFoundError,
  ConflictError,
  ServerError,
  TimeoutError,
  AbortError,
  errorsHashToArray,
  errorsArrayToHash,
} from './adapters/errors';

// maybe public ?
export {
  default as recordDataFor,
  relationshipsFor,
  relationshipStateFor,
} from './system/record-data-for';
export { default as normalizeModelName } from './system/normalize-model-name';
export { modelHasAttributeOrRelationshipNamedType } from './utils';
export { default as coerceId } from './system/coerce-id';
export { default as parseResponseHeaders } from './utils/parse-response-headers';

export { default as isEnabled } from './features';
// `ember-data-model-fragments` relies on `RootState` and `InternalModel`
export { default as RootState } from './system/model/states';
export { default as InternalModel } from './system/model/internal-model';
export { default as RecordData } from './system/model/record-data';

export { PromiseArray, PromiseObject, PromiseManyArray } from './system/promise-proxies';

export { RecordArray, AdapterPopulatedRecordArray } from './system/record-arrays';

export { default as ManyArray } from './system/many-array';
export { default as RecordArrayManager } from './system/record-array-manager';
export { default as Relationship } from './system/relationships/state/relationship';

// Should be a different Repo ?
export { default as DebugAdapter } from './system/debug/debug-adapter';

// Used by tests
export { default as diffArray } from './system/diff-array';
export { default as SnapshotRecordArray } from './system/snapshot-record-array';
